## Amy Tanner: 18/06/2015. This R code corresponds to the analysis in: 
## Tanner, A.L., and S.J. Leroux. [submitted]. Effect of Roadside Vegetation Cutting on Moose Browsing. 

## Clear the workspace
rm(list=ls(all=TRUE))

## New dataset required
vegdatacorr<-read.table("E:/Fieldwork Text/Vegetation Plot Sampling/vegdatacorr.csv", header=T, sep=",")
print(vegdatacorr)

## cor.test(vegdata$x, vegdata$y)
## Used to get rho, S, and p-values for Spearman's and cor, t, and p-values for Pearson's
## The following lines of text reproduce Table S6
cor.test(vegdatacorr$treatment_year, vegdatacorr$water_bodies, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$width, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$road_speed, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$gradient_road, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$gradient_tree, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$moose_density, method="spearman")
cor.test(vegdatacorr$treatment_year, vegdatacorr$proportion_of_preferred_plants_14spp, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$width, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$road_speed, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$gradient_road, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$gradient_tree, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$moose_density, method="spearman")
cor.test(vegdatacorr$water_bodies, vegdatacorr$proportion_of_preferred_plants_14spp, method="spearman")
cor.test(vegdatacorr$width, vegdatacorr$road_speed, method="pearson")
cor.test(vegdatacorr$width, vegdatacorr$gradient_road, method="pearson")
cor.test(vegdatacorr$width, vegdatacorr$gradient_tree, method="pearson")
cor.test(vegdatacorr$width, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$width, vegdatacorr$moose_density, method="pearson")
cor.test(vegdatacorr$width, vegdatacorr$proportion_of_preferred_plants_14spp, method="pearson")
cor.test(vegdatacorr$road_speed, vegdatacorr$gradient_road, method="pearson")
cor.test(vegdatacorr$road_speed, vegdatacorr$gradient_tree, method="pearson")
cor.test(vegdatacorr$road_speed, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$road_speed, vegdatacorr$moose_density, method="pearson")
cor.test(vegdatacorr$road_speed, vegdatacorr$proportion_of_preferred_plants_14spp, method="pearson")
cor.test(vegdatacorr$gradient_road, vegdatacorr$gradient_tree, method="pearson")
cor.test(vegdatacorr$gradient_road, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$gradient_road, vegdatacorr$moose_density, method="pearson")
cor.test(vegdatacorr$gradient_road, vegdatacorr$proportion_of_preferred_plants_14spp, method="pearson")
cor.test(vegdatacorr$gradient_tree, vegdatacorr$traffic_region, method="spearman")
cor.test(vegdatacorr$gradient_tree, vegdatacorr$moose_density, method="pearson")
cor.test(vegdatacorr$gradient_tree, vegdatacorr$proportion_of_preferred_plants_14spp, method="pearson")
cor.test(vegdatacorr$traffic_region, vegdatacorr$moose_density, method="spearman")
cor.test(vegdatacorr$traffic_region, vegdatacorr$proportion_of_preferred_plants_14spp, method="spearman")
cor.test(vegdatacorr$moose_density, vegdatacorr$proportion_of_preferred_plants_14spp, method="pearson")

############################################################################################################################################

## New dataset required, with words rather than numeric vectors for some variables in order for analysis to run correctly
vegdataplants2<-read.table("E:/Fieldwork Text/Vegetation Plot Sampling/vegdataplants2.csv", header=T, sep=",")
print(vegdataplants2)

## GLMER with a hierarchical structure using binomial error stucture and logit link with weights added 
library(lme4)
library(arm)
library(Rcpp)
library(RcppEigen)
library(MuMIn)

GLMER_1<-glmer(proportion_browsed_plants~treatment_year+width+traffic_region+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_1)
res1<-resid(GLMER_1)
fit1<-fitted(GLMER_1)
plot(fit1,res1,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Width & Traffic Region", pch=16)
GLMER_2<-glmer(proportion_browsed_plants~treatment_year+width+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_2)
res2<-resid(GLMER_2)
fit2<-fitted(GLMER_2)
plot(fit2,res2,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Width", pch=16)
GLMER_3<-glmer(proportion_browsed_plants~treatment_year+traffic_region+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_3)
res3<-resid(GLMER_3)
fit3<-fitted(GLMER_3)
plot(fit3,res3,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Traffic Region", pch=16)
GLMER_4<-glmer(proportion_browsed_plants~treatment_year+moose_density+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_4)
res4<-resid(GLMER_4)
fit4<-fitted(GLMER_4)
plot(fit4,res4,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Moose Density", pch=16)
GLMER_5<-glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_5)
res5<-resid(GLMER_5)
fit5<-fitted(GLMER_5)
plot(fit5,res5,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year", pch=16)
GLMER_6<-glmer(proportion_browsed_plants~1+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_6)
res6<-resid(GLMER_6)
fit6<-fitted(GLMER_6)
plot(fit6,res6,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Null", pch=16)

## Building Table for AIC, Log Likelihood, Marginal R^2, Conditional R^2, Delta AIC and Akaike Weights
## **** for all models, models with pretending variables have not been removed yet
output<-matrix(nrow=6,ncol=6);rownames(output)<-c("GLMER_1", "GLMER_2", "GLMER_3", "GLMER_4", "GLMER_5", "GLMER_6");
colnames(output)<-c("AIC", "LogLike", "Marginal R^2", "Conditional R^2", "Delta AIC", "Akaike Weights")

## AIC
output[1,1]<-AIC(GLMER_1)
output[2,1]<-AIC(GLMER_2)
output[3,1]<-AIC(GLMER_3)
output[4,1]<-AIC(GLMER_4)
output[5,1]<-AIC(GLMER_5)
output[6,1]<-AIC(GLMER_6)

## Log Likelihood
output[1,2]<-logLik(GLMER_1)[1]
output[2,2]<-logLik(GLMER_2)[1]
output[3,2]<-logLik(GLMER_3)[1]
output[4,2]<-logLik(GLMER_4)[1]
output[5,2]<-logLik(GLMER_5)[1]
output[6,2]<-logLik(GLMER_6)[1]

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(GLMER_1)
Rsq2<-r.squaredGLMM(GLMER_2)
Rsq3<-r.squaredGLMM(GLMER_3)
Rsq4<-r.squaredGLMM(GLMER_4)
Rsq5<-r.squaredGLMM(GLMER_5)
Rsq6<-r.squaredGLMM(GLMER_6)

## Marginal R^2
output[1,3]<-Rsq1[1]
output[2,3]<-Rsq2[1]
output[3,3]<-Rsq3[1]
output[4,3]<-Rsq4[1]
output[5,3]<-Rsq5[1]
output[6,3]<-Rsq6[1]

## Conditional R^2
output[1,4]<-Rsq1[2]
output[2,4]<-Rsq2[2]
output[3,4]<-Rsq3[2]
output[4,4]<-Rsq4[2]
output[5,4]<-Rsq5[2]
output[6,4]<-Rsq6[2]

## Subtracting the lowest AIC from each model AIC
output[1,5]<-AIC(GLMER_1)-min(output[,1])
output[2,5]<-AIC(GLMER_2)-min(output[,1])
output[3,5]<-AIC(GLMER_3)-min(output[,1])
output[4,5]<-AIC(GLMER_4)-min(output[,1])
output[5,5]<-AIC(GLMER_5)-min(output[,1])
output[6,5]<-AIC(GLMER_6)-min(output[,1])

## Akaike weights are the probability that model i is the best model in the set 
## Sum of (exp(0.5*deltaAIC))
sum<-(exp(-0.5*output[1,5])+exp(-0.5*output[2,5])+exp(-0.5*output[3,5])+exp(-0.5*output[4,5])+exp(-0.5*output[5,5]))
## Add in Akaike Weights
output[1,6]<-exp(-0.5*output[1,5])/sum
output[2,6]<-exp(-0.5*output[2,5])/sum
output[3,6]<-exp(-0.5*output[3,5])/sum
output[4,6]<-exp(-0.5*output[4,5])/sum
output[5,6]<-exp(-0.5*output[5,5])/sum
output[6,6]<-exp(-0.5*output[6,5])/sum

output

library(Matrix)
library(lattice)

## GLMER with only 4 models (models wih width removed due to width being a pretending variable) used to determine the direction of the relationship between each variable and the proportion of moose browsed plants
## The following lines of text reproduce Table 3
GLMER_3A<-glmer(proportion_browsed_plants~treatment_year+traffic_region+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_3A)
res3A<-resid(GLMER_3A)
fit3A<-fitted(GLMER_3A)
plot(fit3A,res3A,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Traffic Region", pch=16)
GLMER_4A<-glmer(proportion_browsed_plants~treatment_year+moose_density+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_4A)
res4A<-resid(GLMER_4A)
fit4A<-fitted(GLMER_4A)
plot(fit4A,res4A,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year & Moose Density", pch=16)
GLMER_5A<-glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_5A)
res5A<-resid(GLMER_5A)
fit5A<-fitted(GLMER_5A)
plot(fit5A,res5A,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year", pch=16)
GLMER_6A<-glmer(proportion_browsed_plants~1+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_6A)
res6A<-resid(GLMER_6A)
fit6A<-fitted(GLMER_6A)
plot(fit6A,res6A,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Null", pch=16)

############################################################################################################################################

## 95% Conifdence Intervals

library(AICcmodavg)
library(lme4)

## Model 1 parameter estimates and confidence intervals
Cand.models <- list( )
Cand.models[[1]] <- glmer(proportion_browsed_plants~treatment_year+moose_density+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
##create a vector of names to trace back models in set
Modnames <- c("GLMER_4A")

## treatment1: 2008-2010
parm <- "treatment_yeartrt1"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## treatment2: 2011-3013
parm <- "treatment_yeartrt2"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## moose density
parm <- "moose_density"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## Model 2 parameter estimates and confidence intervals
Cand.models <- list( )
Cand.models[[1]] <- glmer(proportion_browsed_plants~treatment_year+traffic_region+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)

##create a vector of names to trace back models in set
Modnames <- c("GLMER_3A")

## treatment1: 2008-2010
parm <- "treatment_yeartrt1"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## treatment2: 2011-3013
parm <- "treatment_yeartrt2"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## traffic region: YES (on avalon)
parm <- "traffic_regionYES"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## Model 3 parameter estimates and confidence intervals
Cand.models <- list( )
Cand.models[[1]] <- glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
##create a vector of names to trace back models in set
Modnames <- c("GLMER_5A")

## treatment1: 2008-2010
parm <- "treatment_yeartrt1"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

## treatment2: 2011-3013
parm <- "treatment_yeartrt2"
##generate AICc table
modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

#Building Table for AIC, Log Likelihood, Marginal R^2, Conditional R^2, Delta AIC and Akaike Weights
## The following lines of text reproduce Table 2
output<-matrix(nrow=4,ncol=6);rownames(output)<-c("GLMER_3A", "GLMER_4A", "GLMER_5A", "GLMER_6A");
colnames(output)<-c("AIC", "LogLike", "Marginal R^2", "Conditional R^2", "Delta AIC", "Akaike Weights")

## AIC
output[1,1]<-AIC(GLMER_3A)
output[2,1]<-AIC(GLMER_4A)
output[3,1]<-AIC(GLMER_5A)
output[4,1]<-AIC(GLMER_6A)

## Log Likelihood
output[1,2]<-logLik(GLMER_3A)[1]
output[2,2]<-logLik(GLMER_4A)[1]
output[3,2]<-logLik(GLMER_5A)[1]
output[4,2]<-logLik(GLMER_6A)[1]

## Pseudo-R-squared for Generalized Mixed-Effect models
Rsq3A<-r.squaredGLMM(GLMER_3A)
Rsq4A<-r.squaredGLMM(GLMER_4A)
Rsq5A<-r.squaredGLMM(GLMER_5A)
Rsq6A<-r.squaredGLMM(GLMER_6A)

## Marginal R^2
output[1,3]<-Rsq3A[1]
output[2,3]<-Rsq4A[1]
output[3,3]<-Rsq5A[1]
output[4,3]<-Rsq6A[1]

## Conditional R^2
output[1,4]<-Rsq3A[2]
output[2,4]<-Rsq4A[2]
output[3,4]<-Rsq5A[2]
output[4,4]<-Rsq6A[2]

## Subtracting the lowest AIC from each model AIC
output[1,5]<-AIC(GLMER_3A)-min(output[,1])
output[2,5]<-AIC(GLMER_4A)-min(output[,1])
output[3,5]<-AIC(GLMER_5A)-min(output[,1])
output[4,5]<-AIC(GLMER_6A)-min(output[,1])

## Akaike weights are the probability that model i is the best model in the set. 
## Sum of (exp(0.5*deltaAIC))
sum<-(exp(-0.5*output[1,5])+exp(-0.5*output[2,5])+exp(-0.5*output[3,5]))
## Add in Akaike Weights
output[1,6]<-exp(-0.5*output[1,5])/sum
output[2,6]<-exp(-0.5*output[2,5])/sum
output[3,6]<-exp(-0.5*output[3,5])/sum
output[4,6]<-exp(-0.5*output[4,5])/sum

output

## using AICcmodavg to obtain k values
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glmer(proportion_browsed_plants~treatment_year+traffic_region+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
Cand.models[[2]] <- glmer(proportion_browsed_plants~treatment_year+moose_density+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
Cand.models[[3]] <- glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
Cand.models[[4]] <- glmer(proportion_browsed_plants~1+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)

##create a vector of names to trace back models in set
Modnames <- c("GLMER_3A", "GLMER_4A", "GLMER_5A", "GLMER_6A")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

modavg(cand.set = Cand.models, parm, modnames = Modnames, second.ord=TRUE, uncond.se ="revised", conf.level = 0.95, warn=FALSE)

############################################################################################################################################

## Looking at the differences between the proportion of browsed plants in the treatment and control areas

## Boxplot for median proportion of plants browsed for control, treatment 1 and treatment 2
## Used to obtain the median values for each of the control and treatment groups used for jitter plot below
boxplot(proportion_browsed_plants~treatment_year, data=vegdataplants2, ylab="Proportion of Plants Browsed",xlab="Control and Treatment Groups",main="Comparison of the Proportion of Plants Browsed\n in the Control and Year Separated Treatment Groups")
boxplot(proportion_browsed_plants~treatment_year, plot=FALSE, data=vegdataplants2)
library(doBy)
summaryBy(proportion_browsed_plants~treatment_year, data=vegdataplants2, FUN = list(mean, max, min, median, sd))

## Jitter plot showing the proportion of moose browsed plants in the control and year seperated treatment groups + the median value for each group
## The following lines of text reproduce Figure 4
par(mar=c(5, 5, 3, 3))
plot(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="REN"]), vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="REN"], pch=0, ylab="Proportion of plants browsed", xlab="Control and treatment groups", xlim= c(-0.5,2.5), xaxt="n", ylim=c(0,1), cex=1.5, cex.lab=1.5, cex.axis=1.5)
axis(1, c(0, 1, 2), cex.axis=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="MAN"]),vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="MAN"], pch=1, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="SPA"]),vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="SPA"], pch=2, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="GFW"]),vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="GFW"], pch=6, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="BAD"]),vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="BAD"], pch=8, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="GAN"]),vegdatacorr$proportion_browsed_plants[vegdatacorr$site_id=="GAN"], pch=7, cex=1.5)
legend("topright", legend=c("REN", "MAN", "SPA", "GFW", "BAD", "GAN"), pch=c(0, 1, 2, 6, 8, 7), ncol=2, cex=1.5)
segments(x0=-0.4, y0=0.12825, x1=0.4, y1=0.12825, lwd=3)
segments(x0=0.75, y0=0.02260, x1=1.25, y1=0.02260, lwd=3)
segments(x0=1.6, y0=0.00000, x1=2.4, y1=0.00000, lwd=3)

############################################################################################################################################

## New dataset required to run the analysis
vegdataplantswilcox<-read.table("E:/Fieldwork Text/Vegetation Plot Sampling/vegdataplantswilcox.csv", header=T, sep=",")
print(vegdataplantswilcox)

## Mann-Whitney test for significant difference between treatment 1 sites and control sites 
wilcox.test(proportion_browsed_plants_a~ctrl_trt1, data=vegdataplantswilcox)
library(doBy)
summaryBy(proportion_browsed_plants_a~ctrl_trt1, data=vegdataplantswilcox, FUN = list(mean, max, min, median, sd))

## Mann-Whitney test for significant difference between treatment 2 sites and control sites
wilcox.test(proportion_browsed_plants_b~ctrl_trt2, data=vegdataplantswilcox)
library(doBy)
summaryBy(proportion_browsed_plants_b~ctrl_trt2, data=vegdataplantswilcox, FUN = list(mean, max, min, median, sd))

## Mann-Whitney test for significant difference between treatment 1 sites and treatment 2 sites
wilcox.test(proportion_browsed_plants_c~trt1_trt2, data=vegdataplantswilcox)
library(doBy)
summaryBy(proportion_browsed_plants_c~trt1_trt2, data=vegdataplantswilcox, FUN = list(mean, max, min, median, sd))

############################################################################################################################################

## New dataset required to run the analysis
vegdataperplantspp<-read.table("E:/Fieldwork Text/Vegetation Plot Sampling/vegdataperplantspp.csv", header=T, sep=",")
print(vegdataperplantspp)

## Segmented analysis to determine the breakpoint for preferred or high "quality" plants species 
## The following lines of text reproduce Figure 3
library(segmented)
lin.mod<-lm(proportion_of_browsed_plants_by_species~species_order, data=vegdataperplantspp)
segmented.mod<-segmented(lin.mod, seg.Z=~species_order, psi=21)
summary(segmented.mod)
par(mar = c(5, 5, 5, 5))
plot(segmented.mod, main="Breakpoint Analysis for Plant Quality", xlab="Order of plant species", ylim=c(0,0.8), ylab="Proportion of plants browsed", lwd=2.5)
points(proportion_of_browsed_plants_by_species~species_order, data=vegdataperplantspp, cex=3)
slope(segmented.mod)
intercept(segmented.mod)
summary(segmented.mod)

############################################################################################################################################

## Looking to see if there is a correlation between the proportion of browsed plants and the proportion of preferred plants per site
cor.test(vegdataplants2$proportion_of_preferred_plants_14spp, vegdataplants2$proportion_browsed_plants)

## Boxplots for the proportion of browsed plants and the proportion of preferred plants per site (14 spp)
## The following lines of text reproduce Figure S5
par(mar=c(5, 7, 3, 3))
par(mfrow=c(2,1))
## Boxplot for the #number of browsed plants/#of browseable plants per plot
boxplot(proportion_browsed_plants~treatment_year*site_id, ylim=c(0,1), ylab="Proportion of browseable \n plants browsed", xlab="Site identification", data=vegdataplants2, col=rgb(0.25,0.25,0.25), cex.axis=1.5, cex.lab=1.5)

## Boxplot for proportion of preferred plants per plot (using 14 species)
boxplot(proportion_of_preferred_plants_14spp~treatment_year*site_id, ylim=c(0,1), ylab="Proportion of preferred \n plants", xlab="Site identification", data=vegdataplants2, col=rgb(0.5,0.5,0.5), cex.axis=1.5, cex.lab=1.5)

## Plotting the proportion of preferred plants vs the treament types in order to visually display the correlation
## The following lines of text reproduce Figure S7
par(mar=c(5, 5, 3, 3))
plot(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="REN"]), vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="REN"], pch=0, ylab="Proportion of preferred plants", xlab="Control and treatment groups", xlim= c(-0.5,2.5), xaxt="n", ylim=c(0,1.2), cex=1.5, cex.lab=1.5, cex.axis=1.5)
axis(1, c(0, 1, 2), cex.axis=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="MAN"]),vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="MAN"], pch=1, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="SPA"]),vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="SPA"], pch=2, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="GFW"]),vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="GFW"], pch=6, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="BAD"]),vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="BAD"], pch=8, cex=1.5)
points(jitter(vegdatacorr$treatment_year[vegdatacorr$site_id=="GAN"]),vegdatacorr$proportion_of_preferred_plants_14spp[vegdatacorr$site_id=="GAN"], pch=7, cex=1.5)
legend("topright", legend=c("REN", "MAN", "SPA", "GFW", "BAD", "GAN"), pch=c(0, 1, 2, 6, 8, 7), ncol=6, cex=1.5)

############################################################################################################################################

## Looking to see if there is a correlation between preferred or high quality plants and treatment type 
cor.test(vegdatacorr$treatment_year, vegdatacorr$proportion_of_preferred_plants_14spp, method="spearman")

## Determining if preferred (or high quality) plants or treatment type is the most parsimonious to explain the proportion of moose browsed plants
library(lme4)
library(arm)
library(Rcpp)
library(RcppEigen)
library(MuMIn)
GLMER_1T<-glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_1T)
res1<-resid(GLMER_1T)
fit1<-fitted(GLMER_1T)
plot(fit1,res1,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Treatment Year", pch=16)
GLMER_2T<-glmer(proportion_browsed_plants~proportion_of_preferred_plants_14spp+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
summary(GLMER_2T)
res2<-resid(GLMER_2T)
fit2<-fitted(GLMER_2T)
plot(fit2,res2,ylab="Residuals",xlab="Fitted Values",main="Proportion of Browse Residuals vs Fits\n Preferred Plants", pch=16)

## Building Table for AIC, Log Likelihood, Marginal R^2, Conditional R^2, Delta AIC and Akaike Weights
## The following lines of text reproduce Table S8
output<-matrix(nrow=2,ncol=6);rownames(output)<-c("Treatment", "Preferred");
colnames(output)<-c("AIC", "LogLike", "Marginal R^2", "Conditional R^2", "Delta AIC", "Akaike Weights")

## AIC
output[1,1]<-AIC(GLMER_1T)
output[2,1]<-AIC(GLMER_2T)

## Log Likelihood
output[1,2]<-logLik(GLMER_1T)[1]
output[2,2]<-logLik(GLMER_2T)[1]

## Pseudo-R-squared for Generalized Mixed-Effect Models
Rsq1<-r.squaredGLMM(GLMER_1T)
Rsq2<-r.squaredGLMM(GLMER_2T)

## Marginal R^2
output[1,3]<-Rsq1[1]
output[2,3]<-Rsq2[1]

## Conditional R^2
output[1,4]<-Rsq1[2]
output[2,4]<-Rsq2[2]

## Subtracting the lowest AIC from each model AIC
output[1,5]<-AIC(GLMER_1T)-min(output[,1])
output[2,5]<-AIC(GLMER_2T)-min(output[,1])

## Akaike weights are the probability that model i is the best model in the set 
## Sum of (exp(0.5*deltaAIC))
sum<-(exp(-0.5*output[1,5])+exp(-0.5*output[2,5]))
## Add in Akaike Weights
output[1,6]<-exp(-0.5*output[1,5])/sum
output[2,6]<-exp(-0.5*output[2,5])/sum

output

## using AICcmodavg to obtain k values
library(AICcmodavg)
Cand.models <- list( )
Cand.models[[1]] <- glmer(proportion_browsed_plants~treatment_year+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)
Cand.models[[2]] <- glmer(proportion_browsed_plants~proportion_of_preferred_plants_14spp+(1|site_id/plot_number), family=binomial(link="logit"), data=vegdataplants2, weights=sample_size)

##create a vector of names to trace back models in set
Modnames <- c("GLMER_1T", "GLMER_2T")

##generate AICc table
aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE)
##round to 4 digits after decimal point and give log-likelihood
print(aictab(cand.set = Cand.models, modnames = Modnames, sort = TRUE),
      digits = 4, LL = TRUE)

